@@ -1,22 +1,21 @@
 /*
-    GNU Gama -- adjustment of geodetic networks
-    Copyright (C) 2004  Jan Pytel  <pytel@gama.fsv.cvut.cz>
+  GNU Gama -- adjustment of geodetic networks
+  Copyright (C) 2004  Jan Pytel  <pytel@gama.fsv.cvut.cz>
 
-    This file is part of the GNU Gama C++ library.
+  This file is part of the GNU Gama C++ library.
 
-    This library is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 3 of the License, or
-    (at your option) any later version.
+  This library is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 3 of the License, or
+  (at your option) any later version.
 
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
+  This library is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this library; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  You should have received a copy of the GNU General Public License
+  along with GNU Gama.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 /** \file reduced_observations_to_ellipsoid.h
@@ -73,9 +72,9 @@ void ReducedObservationsToEllipsoidText(GNU_gama::local::LocalNetwork* IS,
            if ( ci == reduced.end() )
                continue;
 
-	   Double orig_value = ci->second;
-           Double value      = o->value();
-	   Double diff       = R2G*(value - orig_value);
+	   double orig_value = ci->second;
+           double value      = o->value();
+	   double diff       = R2G*(value - orig_value);
 
 	   int oz = 0;
 	   int dz = 0;
@@ -167,7 +166,7 @@ void ReducedObservationsToEllipsoidText(GNU_gama::local::LocalNetwork* IS,
        if ( ci == reduced.end() )
            continue;
 
-       Double orig_value = ci->second;
+       double orig_value = ci->second;
 
        Observation* pm = *i;
 
