@@ -1,22 +1,21 @@
 /*
-    GNU Gama -- adjustment of geodetic networks
-    Copyright (C) 2002, 2005  Ales Cepek <cepek@gnu.org>
+  GNU Gama -- adjustment of geodetic networks
+  Copyright (C) 2002, 2005, 2018  Ales Cepek <cepek@gnu.org>
 
-    This file is part of the GNU Gama C++ library
+  This file is part of the GNU Gama C++ library
 
-    This library is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 3 of the License, or
-    (at your option) any later version.
+  This library is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 3 of the License, or
+  (at your option) any later version.
 
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
+  This library is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this library; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  You should have received a copy of the GNU General Public License
+  along with GNU Gama.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 #include <gnu_gama/xml/dataparser.h>
@@ -776,7 +775,7 @@ int DataParser::g3_obs(const char *name)
   using namespace g3;
 
   int obs_dim = 0;
-  for (List<g3::Observation*>::const_iterator
+  for (std::list<g3::Observation*>::const_iterator
          i=g3->obs_cluster->observation_list.begin(),
          e=g3->obs_cluster->observation_list.end();  i!=e;  ++i)
     {
@@ -810,8 +809,8 @@ int DataParser::g3_obs(const char *name)
     {
       const CovMat<>& cov = *i;
 
-      for (size_t i=1; i<=cov.dim(); i++)
-        for (size_t j=0; j<=cov.bandWidth() && i+j<=cov.dim(); j++)
+      for (int i=1; i<=cov.dim(); i++)
+        for (int j=0; j<=cov.bandWidth() && i+j<=cov.dim(); j++)
           g3->obs_cluster->covariance_matrix(offset+i, offset+i+j) = cov(i, i+j);
 
       offset += cov.dim();
@@ -1191,7 +1190,7 @@ int DataParser::g3_const_tol_abs(const char *name)
   return error("### bad <tol-abs>");
 }
 
-int DataParser::g3_const_ellipsoid_id(const char *name)
+int DataParser::g3_const_ellipsoid_id(const char * /*name*/)
 {
   using namespace g3;
   stringstream istr(text_buffer);
